@@ -19,7 +19,7 @@
  * USA
  *
  * --------------------------------------------------------------------------
- * $Id: CamelServlet.java 21288 2011-05-19 21:55:46Z renaultgu $
+ * $Id: CamelServlet.java 21408 2011-06-10 18:46:00Z alitokmen $
  * --------------------------------------------------------------------------
  */
 package org.ow2.jonas.camel.component;
@@ -28,7 +28,11 @@ import org.apache.camel.CamelContext;
 import org.apache.camel.Exchange;
 import org.apache.camel.Producer;
 
-import javax.servlet.*;
+import javax.servlet.Servlet;
+import javax.servlet.ServletConfig;
+import javax.servlet.ServletException;
+import javax.servlet.ServletRequest;
+import javax.servlet.ServletResponse;
 import javax.servlet.http.HttpServletResponse;
 import javax.ws.rs.core.HttpHeaders;
 import java.io.IOException;
